Plane class

A single color plane of image data.

The number and meaning of the planes in an image are determined by the format of the Image.

Properties

bytes → Uint8List?
Bytes representing this plane.
final
bytesPerPixel → int?
The distance between adjacent pixel samples on Android, in bytes.
final
bytesPerRow → int?
The row stride for this color plane, in bytes.
final
hashCode → int
The hash code for this object.
no setterinherited
height → int?
Height of the pixel buffer on iOS.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → int?
Width of the pixel buffer on iOS.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited