CameraInfo class

Information about a camera.

Retrieved from Camera.getCameraInfo.

Implemented types

Constructors

CameraInfo({required int id, required Facing facing, required int orientation})
const
CameraInfo.fromMap(Map<String, dynamic> map)
factory

Properties

direction → LensDirection?
Location of the camera on the device.
no setteroverride
facing → Facing
The direction that the camera faces.
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
Identifier for a particular camera.
final
name → String
Identifier for this camera.
no setteroverride
orientation → int
The orientation of the camera image.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited